##############################################################################
#    Copyright (C) 2001  MMmanager.org
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##############################################################################
"""
"""

ADD_CONTENT_PERMISSION = 'Add portal content'

import xmlrpclib
import zLOG
import Globals
from Globals import PersistentMapping
from Persistence import Persistent

from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore.WorkflowCore import WorkflowMethod

from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from AccessControl import ClassSecurityInfo
from General import videoinputs, videostandards, audioinputs


factory_type_information = {
      'id': 'Encoder',
      'meta_type': 'Media Manager Encoder',
      'description': 'Use master file to store link to files',
      'product': 'MyMediaManager',
      'icon': 'file_icon.gif',
      'factory': 'addEncoder',
      'filter_content_types': 0,
      'immediate_view': 'encoder_edit_form',
      'actions': 
	      ({'name': 'View',
	        'action': 'encoder_view',
		'permissions': ('View',),
		'category': 'object'},
	       {'name': 'Edit',
	        'action': 'encoder_edit_form',
		'permissions': ('Modify portal content',)})
       }

class Encoder( PortalContent
            , DefaultDublinCoreImpl
            ):
    """
    An Encoder Object
    """

    meta_type='Media Manager Encoder'
    portal_type='Object'
    effective_date = expiration_date = None
    _isDiscussable = 1
    object_id = None
    video_input = None
    audio_input = None
    video_standard = None
    video_colorspace = None
    videoinputs = videoinputs
    videostandards = videostandards
    audioinputs = audioinputs

    security = ClassSecurityInfo()

    def __init__( self
                , id
                , title=''
                , description=''
                ):
        DefaultDublinCoreImpl.__init__(self)
        self.id=id
        self.title=title
        self.description=description

    def edit (self, title=None, description=None, object_id=None, audio_input=None, video_input=None, video_standard=None, video_colorspace=None):
        
        if title is not None:
            self.setTitle(title)

        if description is not None:
            self.setDescription(description)

        if object_id is not None:
            self.object_id = object_id

        if audio_input is not None:
            self.audio_input = audio_input

        if video_input is not None:
            self.video_input = video_input

        if video_standard is not None:
            self.video_standard = video_standard

        if video_colorspace is not None:
            self.video_colorspace = video_colorspace

    def setup(self, par=None):
        """
        Used to setup encoder before starting
        """
    
        if self.portal_properties.mmm_server is None:
            raise Error, 'Encoder server is None'
   
        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
        
        if par is None:
            par = {}

        par['audio-input'] = self.audio_input
        par['video-input'] = self.video_input
        par['video-standard'] = self.video_standard
        par['video-colorspace'] = self.video_colorspace
	   
        server = xmlrpclib.Server(self.portal_properties.mmm_server)
        object = getattr(server, self.portal_properties.mmm_encoder)
        object.setup(self.object_id, par)

    def start(self, par=None):
        """
        Start the encoder
        """
    
        if self.portal_properties.mmm_server is None:
            raise Error, 'Encoder server is None'
   
        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
        
        server = xmlrpclib.Server(self.portal_properties.mmm_server)
        object = getattr(server, self.portal_properties.mmm_encoder)
        object.unsetup(self.object_id)
        object.setup(self.object_id, par)
        object.start(self.object_id)

    def stop(self):
        """
        Stop the encoder
        """

        if self.portal_properties.mmm_server is None:
            raise Error, 'Encoder server is None'
   
        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
   
        server = xmlrpclib.Server(self.portal_properties.mmm_server)
        object = getattr(server, self.portal_properties.mmm_encoder)
        object.stop(self.object_id)
        object.unsetup(self.object_id)
	
    def unsetup(self):
        """
        unsets the setup
        """

        if self.portal_properties.mmm_server is None:
            raise Error, 'Encoder server is None'

        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
   
        server = xmlrpclib.Server(self.portal_properties.mmm_server)
        object = getattr(server, self.portal_properties.mmm_encoder)
        object.unsetup(self.object_id)


    def isEncoding(self):
        """
        Returns the status of the encoder
        """

        if self.portal_properties.mmm_server is None:
            raise Error, 'Encoder server is None'
   
        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
   
        server = xmlrpclib.Server(self.portal_properties.mmm_server)
        object = getattr(server, self.portal_properties.mmm_encoder)
        return object.isEncoding(self.object_id)
 
    def getError(self):
        """
        Returns last error Encounted.
        """
        return ""

    def getControls(self):
        """
        Read control values from the Encoder
        """
        par = {'audio_level'      : 78,
	           'video_hue'        : 245,
	           'video_brightness' : 50,
    	       'video_contrast'   : 51,
	           'video_saturation' : 52
	          }

        if self.portal_properties.mmm_server is None:
           raise Error, 'Encoder server is None'
   
        if self.portal_properties.mmm_encoder is None:
            raise Error, 'Encoder name is None'

        if self.object_id is None:
            raise Error, 'Object id is None'
   
        return par;

    def SearchableText(self):
        """
        text for indexing
        """
        return "%s %s" % (self.title, self.description)

    def cb_isMoveable(self):
        return 1

    def cb_isCopyable(self):
        """
        You can copy this object
        """
        return 1

def addEncoder(self, id, title='', REQUEST=None):
	ob = Encoder(id, title)
	self._setObject(id, ob)

Globals.InitializeClass(Encoder)

from Products.CMFCore.register import registerPortalContent
registerPortalContent(Encoder,
                      constructors=(addEncoder,),
		      action='encoder_edit_form',
		      icon='file_icon.gif')
