##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
#
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
#
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
#
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
"""
"""

ADD_CONTENT_PERMISSION = 'Add portal content'

#Globals
import Globals
import zLOG
from os.path import join
import os
import shutil

#Zope
from DateTime.DateTime import DateTime
from AccessControl import ClassSecurityInfo, getSecurityManager
from Persistence import Persistent
from Acquisition import aq_parent, aq_inner, aq_base

#CMF
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFCore.WorkflowCore import WorkflowAction
from Products.CMFCore.utils import getToolByName, tuplize
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.PortalFolder import PortalFolder

#MMManager
import General
from General import *
from Encoder import Encoder
from ServerLogic import ServerLogic

factory_type_information = {
      'id': 'Live Event',
      'meta_type': 'Media Manager Live Event',
      'description': 'Use live events to create new streaming events',
      'product': 'MyMediaManager',
      'icon': 'liveevent_icon.gif',
      'factory': 'addMediaLiveEvent',
      'filter_content_types': 0,
      'immediate_view': 'liveevent_edit_form',
      'actions':
          ({'id': 'view',
            'name': 'View',
            'action': 'liveevent_view',
            'permissions': ('View',),
            'category': 'object'},
           {'id': 'edit',
            'name': 'Edit',
            'action': 'liveevent_edit_form',
            'permissions': ('Manage properties',),
            'category': 'object'},
           { 'id'            : 'syndication',
            'name'          : 'Syndication',
            'action'        : 'synPropertiesForm',
            'permissions'   : (CMFCorePermissions.ManageProperties,),
            'category'      : 'folder'},
           {'id': 'videostream',
            'name': 'Videostream',
            'action': 'streaminfo_edit_form',
            'permissions': ('Manage properties',),
            'category': 'object'},
           {'id': 'editsuite',
            'name': 'Edit Suite',
            'action': 'edit_suite',
            'permissions': ('Manage properties',),
            'category': 'object'},
           {'id': 'prg_editor',
            'name': 'Agenda',
            'action': 'prg_editor_frameset',
            'permissions': ('Manage properties',),
            'category': 'object'}
        )
       }

def _dateStrings(when):
    strings = {}
    if when is not None:
       strings['year'] = str(when.year())
       strings['month'] = str(when.month())
       strings['day'] = str(when.day())
    else:
       strings['year'] = ''
       strings['month'] = ''
       strings['day'] = ''
    return strings

class MediaLiveEvent( PortalFolder
            , PortalContent
            , DefaultDublinCoreImpl
            , Playable
          	):
    """
        A Live Event
    """

    meta_type='Media Manager Live Event'
    portal_type='Object'
    effective_date = expiration_date = None
    _isDiscussable = 1
    _isShow = 1
    _ratingUsers = {}
    _Rating = -1
    Rating = -1
    files = []
    eventpic_path = ''
    bandwidths = bandwidths
    videoqualities = videoqualities
    audienceratings = audienceratings
    audioformats = audioformats
    last_encoder = None

    _repository = ['usr', 'local', 'ZopeDemo', 'var', 'real', 'encoder']

    security = ClassSecurityInfo()

    def __init__( self
                , id
                , title=''
                , description=''
        , effective_date = None
        , expiration_date = None
        , start_date = str(DateTime())
        , end_date = str(DateTime())
                ):
        DefaultDublinCoreImpl.__init__(self, id, title)
        self.id = id
        self._ratingUsers = {}
        self._Rating = -1
        self.Rating = -1
        self.description = description
        self.location = ''
        self.contact_name = ''
        self.contact_email = ''
        self.contact_phone = ''
        self.event_url = ''
        self.encpass = ''
        username = str(getSecurityManager().getUser())
        copytime = str(DateTime().strftime('%Y'))
        copytext = 'Copyright %s' % (copytime)
        self.author = username
        self.setRights(copytext)
        self.files = []
        self.included_shows = []
        self.smils = ['']
        self.current_smil = None
        self.setStartDate(DateTime(start_date))
        self.eventpic_path = ''
        self.last_encoder = None

    #
    # Workflow interaction
    #

    security.declarePrivate('manage_afterAdd')
    def manage_afterAdd(self, item, container):
        " Add self to the workflow and catalog. "
        # Recurse in the children (ObjectManager)
        PortalFolder.manage_afterAdd(self, item, container)
        # Add self to workflow and catalog
        PortalContent.manage_afterAdd(self, item, container)

    security.declarePrivate('manage_beforeDelete')
    def manage_beforeDelete(self, item, container):
        " Remove self from the workflow and catalog. "
        # We don't call PortalContent.manage_beforeDelete because
        #  it deals with talkbacks which are subobjects...
        # Remove self from catalog
        if aq_base(container) is not aq_base(self):
            self.unindexObject()
        # Then recurse in the children (ObjectManager)
        PortalFolder.manage_beforeDelete(self, item, container)

    security.declarePrivate('_datify')
    def _datify(self, date):
        if date == 'None':
           date = None
        elif not isinstance(date, DateTime):
           if date is not None:
              date = DateTime(date)
        return date

    security.declarePrivate('_initEvent')
    def _initEvent(self):
        """
        Set the live encoding default parameters
        """
        catalog = getToolByName(self, 'portal_catalog')
        membership = getToolByName(self, 'portal_membership')
        medianet = getToolByName(self, 'portal_mediamanager').getMedianetFor(self)
        #livelogic = self.restrictedTraverse(medianet.getDefaultLive)
        #zLOG.LOG('Live event', zLOG.INFO, 'Medianet default value: %s' % (medianet.getDefaultLive))
        logic_index = int(medianet.default_live)
        livelogic = self.restrictedTraverse(medianet.getLiveLogic(logic_index))
        try:
           encoderpass = membership.getAuthenticatedMember().enc_pass
        except:
           encoderpass = ''
        self.edit(encpass = encoderpass
            , xsize = livelogic.xsize
            , ysize = livelogic.ysize
            , bandwidth = livelogic.bandwidth
            , audioformat = livelogic.audioformat
            , audience_rate = livelogic.audience_rate
            , video_quality = livelogic.video_quality
            , transport = livelogic.transport)

        """
        Create a masterfile object
        """
        self.addFile()

        """
        Create a show object
        """
        showid = 'Show01'
        self.invokeFactory(id = showid, type_name = 'Show')
        for show in self.objectValues('Media Manager Show'):
            self.addShow(show.absolute_url(relative=1))

    security.declarePublic('getStartStrings')
    def getStartStrings(self):
        return _dateStrings(self.start())

    security.declarePublic('getEndStrings')
    def getEndStrings(self):
        return _dateStrings(self.end())

    def SearchableText(self):
        """
            text for indexing
        """
        return "%s %s" % (self.title, self.description)

    def getRelated(self):
        if self.logic != '':
            l_path = str(self.logic)
            l_obj = self.aq_parent.restrictedTraverse(l_path)
            return "%s://%s%s%s" % (l_obj.protocol, l_obj.ppv_serverid, l_obj.path, self.filename)

    def Related(self):
        relate = []
        relate.append(self.getRelated())
        return tuplize('relate', relate)

    def edit(self
           , title = None
           , description = None
           , category = None
           , effectiveDay = None
           , effectiveMonth = None
           , effectiveYear = None
           , expirationDay = None
           , expirationMonth = None
           , expirationYear = None
           , start_time = None
           , stop_time = None
           , location = None
           , contact_name = None
           , contact_email = None
           , contact_phone = None
           , smil = None
           , slideshow = None
           , event_url = None
           , encpass = None
           , xsize = None
           , ysize = None
           , bandwidth = None
           , audioformat = None
           , audience_rate = None
           , video_quality = None
           , author = None
           , Rights = None
           , transport = None
           , eventpic_path = None
           ):

        if title is not None:
            self.setTitle(title)

        if description is not None:
            self.setDescription(description)

        if category is not None:
            self.setSubject(category)

        if effectiveDay is not None:
            efdate = '%s/%s/%s %s' % (effectiveDay, effectiveMonth, effectiveYear, start_time)
            self.setStartDate(DateTime(efdate))

        if expirationDay is not None:
            exdate = '%s/%s/%s %s' % (expirationDay, expirationMonth, expirationYear, stop_time)
            self.setEndDate(DateTime(exdate))

        if location is not None:
            self.location = location

        if contact_name is not None:
            self.contact_name = contact_name

        if contact_email is not None:
            self.contact_email = contact_email

        if contact_phone is not None:
            self.contact_phone = contact_phone

        if smil is not None:
            self.setSmil(smil)

        if slideshow is not None:
            self.setSlideshow(slideshow)

        if event_url is not None:
            self.event_url = event_url

        if encpass is not None:
            self.encpass=encpass

        if xsize is not None:
            self.xsize=xsize

        if ysize is not None:
            self.ysize=ysize

        if bandwidth is not None:
            self.bandwidth=bandwidth

        if audioformat is not None:
            self.audioformat=audioformat

        if audience_rate is not None:
            self.audience_rate=audience_rate

        if video_quality is not None:
            self.video_quality=video_quality

        if Rights is not None:
            self.setRights(Rights)

        if author is not None:
            self.author=author

        if transport is not None:
            self.transport=transport

        if eventpic_path is not None:
            self.eventpic_path = eventpic_path

        self.reindexObject()

    security.declarePublic('buildHours')
    def buildHours(self):
        result = []
        for hour in range (1,25):
            result.append('%02d' % hour)
        return result

    security.declarePublic('buildTenMin')
    def buildTenMin(self):
        result = []
        for min in range (0, 6):
            result.append('%01d' % min)
        return result

    security.declarePublic('buildOneMin')
    def buildOneMin(self):
        result = []
        for min in range (0, 10):
            result.append('%01d' % min)
        return result

    security.declarePublic('buildDays')
    def buildDays(self):
        result = []
        for day in range (1, 32):
            result.append('%d' % day)
        return result

    security.declarePublic('buildMonths')
    def buildMonths(self):
        result = []
        for month in range (1, 13):
            result.append('%d' % month)
        return result

    security.declarePublic('buildYears')
    def buildYears(self):
        result = []
        start = (DateTime().year() - 2)
        end = (DateTime().year() + 5)
        for year in range (start, end):
            result.append(str(year))
        return result

    def setStartDate(self, date):
        self.start_date = self._datify(date)

    def setEndDate(self, date):
        self.end_date = self._datify(date)

    security.declarePublic('start')
    def start(self):
        date = getattr(self, 'start_date', None)
        return date is None and self.created() or date

    security.declarePublic('end')
    def end(self):
        date = getattr(self, 'end_date', None)
        return date is None and self.start() or date

    security.declarePublic('getStartTimeString')
    def getStartTimeString(self):
        return self.start().AMPMMinutes()

    security.declarePublic('getStopTimeString')
    def getStopTimeString(self):
        return self.end().AMPMMinutes()

    security.declarePublic('getEventPicture')
    def getEventPicture(self):
        if self.eventpic_path != '':
            try:
                imgobj = self.restrictedTraverse(self.eventpic_path)
            except:
                imgobj = None
        else:
            imgobj = None
        
        return imgobj

    security.declarePublic('getEventPictureSrc')
    def getEventPictureSrc(self):
        portal = getToolByName(self, 'portal_url').getPortalObject()
        portalurl = portal.absolute_url()
        if self.eventpic_path != '':
            zLOG.LOG('Live event', zLOG.INFO, 'Picpath is not empty')
            try:
                imgobj = self.restrictedTraverse(self.eventpic_path)
                imgsrc = imgobj.absolute_url()
                zLOG.LOG('Live event', zLOG.INFO, 'Img found. Source is: %s' % imgsrc)
            except:
                imgsrc = portalurl + '/mmm_eventpic.gif'
                zLOG.LOG('Live event', zLOG.INFO, 'Img not found event thoght path not empty')
        else:
            imgsrc = portalurl + '/mmm_eventpic.gif'
            zLOG.LOG('Live event', zLOG.INFO, 'Picpath is empty')

        return imgsrc

    security.declarePublic('listFiles')
    def listFiles(self):
        """
        List files included in this live event
        """
        files = []
        ob = self
        while ob is not None and not getattr(ob, '_isPortalRoot', 0):
            ob = aq_parent(aq_inner(ob))

        i = 0
        while i < len(self.files):
            file = self.files[i]
            try:
                if ob.restrictedTraverse(file).meta_type == 'Media Manager Master File':
                    files.append(file)
                    i = i + 1
            except:
                del self.files[i]
                self.p_changed = 1

        return tuple(files)

    security.declarePublic('listFileObjects')
    def listFileObjects(self):
        """
        List file objects included in this live event
        """
        files = []
        ob = self
        while ob is not None and not getattr(ob, '_isPortalRoot', 0):
            ob = aq_parent(aq_inner(ob))

        for file in self.listFiles():
            try:
                files.append(ob.restrictedTraverse(file))
            except:
                pass

        return tuple(files)

    security.declarePublic('getFile')
    def getFile(self, file_index):
        """
        Return the requested file
        """
        index = int(file_index)
        return self.files[index]

    security.declarePublic('getFileObject')
    def getFileObject(self, file_index):
        """
        Return the requested file object
        """
        portal = getToolByName(self, 'portal_url').getPortalObject()
        index = int(file_index)
        try:
            file = portal.restrictedTraverse(self.files[index])
            return file
        except:
            raise "MasterFile not found (MediaLiveEvent.getFileObject())"

    security.declareProtected(ManageProperties, 'deleteFile')
    def deleteFile(self, file_index):
        index = int(file_index)
        if index >= 0 and index < len(self.files):
           del self.files[index]
           self._p_changed = 1
           return 1
        else:
           return 0

    security.declareProtected(ManageProperties, 'addFile')
    def addFile(self):
        mm = getToolByName(self, 'portal_mediamanager')
        newid = mm.getUniqueID()
        self.invokeFactory(id=newid, type_name='Master File')
        file = self._getOb(newid)
        filepath = file.absolute_url(relative=1)
        self.files.append(filepath)
        self._p_changed = 1

    security.declarePublic('listShows')
    def listShows(self):
        """
        List shows included in the presentation for this live event
        """
        zLOG.LOG("MediaLiveEvent", 0, "Listing shows in event: %s" % (self.id))

        shows = []
        ob = self
        while ob is not None and not getattr(ob, '_isPortalRoot', 0):
            ob = aq_parent(aq_inner(ob))
        for show in self.included_shows:
            try:
                if ob.restrictedTraverse(show).meta_type == "Media Manager Show":
                    shows.append(show)
            except:
                pass

        return tuple(shows)

    security.declarePublic('listShowObjects')
    def listShowObjects(self):
        """
        List show objects included in the presentation for this live event
        """
        zLOG.LOG("MediaShow", zLOG.INFO, "Listing show objects\nCurrent:\n%s" % (self.included_shows))
        shows = []
        ob = self
        while ob is not None and not getattr(ob, '_isPortalRoot', 0):
            ob = aq_parent(aq_inner(ob))
        for show in self.listShows():
            try:
                shows.append(ob.restrictedTraverse(show))
            except:
                pass
        return tuple(shows)

    security.declareProtected(View, 'getShow')
    def getShow(self, show_index):
        """
        Return the requested show
        """
        zLOG.LOG("Media Live Event", 0, "Requested show: %s. Returned show: %s" % (show_index, self.included_shows[show_index]))
        return self.included_shows[show_index]

    security.declareProtected(ManageProperties, 'moveUpShow')
    def moveUpShow(self, pIndex):
        index = int(pIndex)
        zLOG.LOG("Media Live Event", 0, "moveUp %s" % (pIndex))
        if index > 0 and index < len(self.included_shows):
            old = self.included_shows[index - 1]
            self.included_shows[index - 1] = self.included_shows[index]
            self.included_shows[index] = old
            self._p_changed = 1

    security.declareProtected(ManageProperties, 'moveDownShow')
    def moveDownShow(self, pIndex):
        index = int(pIndex)
        zLOG.LOG("Media Live Event", 0, "MoveDown %s" % (pIndex))
        if index < len(self.included_shows)-1 and index >= 0:
            old = self.included_shows[index + 1]
            self.included_shows[index + 1] = self.included_shows[index]
            self.included_shows[index] = old
            self._p_changed = 1
            return 1
        else:
            return 0

    security.declareProtected(ManageProperties, 'deleteShow')
    def deleteShow(self, pIndex):
        index = int(pIndex)
        zLOG.LOG("Media Live Event", 0, "parsed index: %s. deleted index: %s" % (index, self.included_shows[index]))
        if index >= 0 and index < len(self.included_shows):
            del self.included_shows[index]
            self._p_changed = 1
            return 1
        else:
            return 0

    security.declareProtected(ManageProperties, 'addShow')
    def addShow(self, show):
        self.included_shows.append(show)
        self._p_changed = 1

    security.declarePublic('getRatingGrades')
    def getRatingGrades(self):
        grades = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10']
        return grades

    security.declareProtected(CMFCorePermissions.View, 'postRating')
    def postRating(self, user=None, rating=None):
        if user == 'Guest': return

        alreadyRatedIt = self._ratingUsers.get(user, None)
        zLOG.LOG("Live Event", 0, "Alreay rated it? %s" % (alreadyRatedIt))
        zLOG.LOG("Live Event", 0, "User about to rate: %s" % (user))
        today = DateTime()

        if alreadyRatedIt:
            today_days = long(today)
            rating_days = long(alreadyRatedIt[1])
            diff = today_days - rating_days
            if diff < 30: return

        self._ratingUsers[user] = (int(rating), today)
        self._computeRating()

        self._p_changed = 1

    security.declarePrivate(CMFCorePermissions.View, '_computeRating')
    def _computeRating(self):
        ratings = self._ratingUsers.items()
        rLen = len(ratings)

        zLOG.LOG("Live Event", 0, "Len of array with rates: %s" % (rLen))

        total = 0
        oldest = None

        for r in ratings:
            total = total + int(r[1][0])
            zLOG.LOG("Live Event", 0, "Total: %s" % (total))
            r_time = r[1][1].millis()
            if oldest == None or r_time < oldest [1]:
                oldest = (r[0], r_time)

        self._Rating = total / rLen
        self.Rating = self._Rating

        if rLen > 100:
            del self._ratingUsers[oldest[0]]

    security.declarePublic('getRating')
    def getRating(self):
        rLen = len(self._ratingUsers)
        zLOG.LOG("Event Rating", 0, "Rating users: %s" % (self._ratingUsers))
        return (self._Rating, rLen)

    security.declarePublic('Rating')
    def Rating(self):
        return self.getRating()

    security.declarePublic('synContentValues')
    def synContentValues(self):
        """
        returns the syndicatable objects.
        """
        clips = ()
        for show in self.listShowObjects():
            clips = clips + show.listClipObjects()
        zLOG.LOG("synContentValues", 0, "clips: %s" % str(clips))
        return clips

    security.declareProtected(ManageProperties, 'setSmil')
    def setSmil(self, smil):
        if not type(smil) == type(""):
            raise ValueError, "MediaLiveEvent.setSmil takes a relative path as argument."
        self.smil = smil

    security.declareProtected(View, 'getSmilPath')
    def getSmilPath(self):
        """
        Return the currently selected smil *path* or the first in the listing or None
        """
        if not hasattr(self, 'smil'):
            self.smil = ''
        zLOG.LOG("Media Live Event.getSmilPath", 0, "Requesting smil: %s" % self.smil)
        return self.smil

    security.declareProtected(View, 'getSmilObject')
    def getSmilObject(self):
        """
        Return the currently selected smil *object* or None
        """
        path = self.getSmilPath()
        if path:
            try:
                smil = self.restrictedTraverse(path)
                if smil.meta_type == 'Media Manager Smil Data':
                    return smil
            except:
                return None
        return None

    security.declareProtected(ManageProperties, 'setSlideshow')
    def setSlideshow(self, slideshow):
        if not type(slideshow) == type(""):
            raise ValueError, "MediaLiveEvent.setSlideshow takes a relative path as argument."
        self.slideshow = slideshow

    security.declareProtected(View, 'getSlideshowPath')
    def getSlideshowPath(self):
        """
        Return the currently selected slideshow *path* or the first in the listing or None
        """
        if not hasattr(self, 'slideshow'):
            self.slideshow = ''
        zLOG.LOG("Media Live Event.getSlideshowPath", 0, "Requesting slideshow: %s" % self.slideshow)
        return self.slideshow

    security.declareProtected(View, 'getSlideshowObject')
    def getSlideshowObject(self):
        """
        Return the currently selected slideshow *object* or the first in the listing or None
        """
        path = self.getSlideshowPath()
        if path is not None:
            try:
                return self.restrictedTraverse(path)
            except:
                return None
        return None

    security.declarePublic('getLastEncoder')
    def getLastEncoder(self):
        return self.last_encoder

    security.declareProtected(ManageProperties, 'setLastEncoder')
    def setLastEncoder(self, encoder=None):
        if encoder is not None:
            self.last_encoder = encoder

def addMediaLiveEvent(self, id, title='', start_date=str(DateTime()), end_date=str(DateTime()), REQUEST=None):
        portalroot = getToolByName(self, 'portal_url').getPortalObject()
        hasnet = 0
        if 'medianet' in portalroot.objectIds():
            medianet = portalroot.restrictedTraverse('medianet')
            if medianet.meta_type == 'Media Manager Medianet':
                hasnet = 1
        if not hasnet:
            raise "You must have a Media Manager Medianet named 'medianet' in the portal root!!!"
        ob=MediaLiveEvent(id,title,start_date=start_date, end_date=end_date)
        self._setObject(id, ob)
        event = self._getOb(id)
        event._initEvent()

Globals.InitializeClass(MediaLiveEvent)

from Products.CMFCore.register import registerPortalContent
registerPortalContent(MediaLiveEvent,
                      constructors=(addMediaLiveEvent,),
                      action='liveevent_edit_form',
                      icon='liveevent_icon.gif')
